# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ItemRankResponse(Model):
    """ItemRankResponse.

    :param type: The item type
    :type type: str
    :param id: The item identifier
    :type id: int
    :param display: The item display name
    :type display: str
    :param secondary_display: The item formated value
    :type secondary_display: str
    :param value: The item value
    :type value: float
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'id': {'key': 'id', 'type': 'int'},
        'display': {'key': 'display', 'type': 'str'},
        'secondary_display': {'key': 'secondaryDisplay', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, *, type: str=None, id: int=None, display: str=None, secondary_display: str=None, value: float=None, **kwargs) -> None:
        super(ItemRankResponse, self).__init__(**kwargs)
        self.type = type
        self.id = id
        self.display = display
        self.secondary_display = secondary_display
        self.value = value
