# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WatticsDataPointChild(Model):
    """WatticsDataPointChild.

    :param wattics_data_point_id: The identifier for a Wattics meter
    :type wattics_data_point_id: int
    :param wattics_data_point_info: The name for a Wattics meter
    :type wattics_data_point_info: str
    """

    _attribute_map = {
        'wattics_data_point_id': {'key': 'watticsDataPointId', 'type': 'int'},
        'wattics_data_point_info': {'key': 'watticsDataPointInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(WatticsDataPointChild, self).__init__(**kwargs)
        self.wattics_data_point_id = kwargs.get('wattics_data_point_id', None)
        self.wattics_data_point_info = kwargs.get('wattics_data_point_info', None)
