# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGVersion(Model):
    """GHGVersion.

    :param effective_date: Effective Date
    :type effective_date: datetime
    :param source: Source
    :type source: str
    :param gases: List of gases per version.
    :type gases: list[~energycap.sdk.models.GHGGas]
    """

    _attribute_map = {
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'source': {'key': 'source', 'type': 'str'},
        'gases': {'key': 'gases', 'type': '[GHGGas]'},
    }

    def __init__(self, **kwargs):
        super(GHGVersion, self).__init__(**kwargs)
        self.effective_date = kwargs.get('effective_date', None)
        self.source = kwargs.get('source', None)
        self.gases = kwargs.get('gases', None)
