# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryObservationTypeChild(Model):
    """BillEntryObservationTypeChild.

    :param observation_type_id: The observation type identifier
    :type observation_type_id: int
    :param observation_type_code: The observation type code
    :type observation_type_code: str
    :param observation_type_info: The observation type name
    :type observation_type_info: str
    """

    _attribute_map = {
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'observation_type_info': {'key': 'observationTypeInfo', 'type': 'str'},
    }

    def __init__(self, *, observation_type_id: int=None, observation_type_code: str=None, observation_type_info: str=None, **kwargs) -> None:
        super(BillEntryObservationTypeChild, self).__init__(**kwargs)
        self.observation_type_id = observation_type_id
        self.observation_type_code = observation_type_code
        self.observation_type_info = observation_type_info
