# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ObservationTypeChild(Model):
    """ObservationTypeChild.

    :param noun_id: The identifier for the observation type's noun
    :type noun_id: int
    :param noun_code: The observation type's noun code
    :type noun_code: str
    :param credit: Indicates the type of credit for the observation type.
     Possible values include: 1 (Credit), 2 (Debit), 3 (Ignore)
    :type credit: int
    :param observation_type_id: The observation type identifier
    :type observation_type_id: int
    :param observation_type_code: The observation type code
    :type observation_type_code: str
    :param observation_type_info: The observation type info
    :type observation_type_info: str
    """

    _attribute_map = {
        'noun_id': {'key': 'nounId', 'type': 'int'},
        'noun_code': {'key': 'nounCode', 'type': 'str'},
        'credit': {'key': 'credit', 'type': 'int'},
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'observation_type_info': {'key': 'observationTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ObservationTypeChild, self).__init__(**kwargs)
        self.noun_id = kwargs.get('noun_id', None)
        self.noun_code = kwargs.get('noun_code', None)
        self.credit = kwargs.get('credit', None)
        self.observation_type_id = kwargs.get('observation_type_id', None)
        self.observation_type_code = kwargs.get('observation_type_code', None)
        self.observation_type_info = kwargs.get('observation_type_info', None)
