# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PeriodRange(Model):
    """General purpose period range DTO.

    :param start_period: The start period for the range
    :type start_period: int
    :param end_period: The end period for the range
    :type end_period: int
    """

    _attribute_map = {
        'start_period': {'key': 'startPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
    }

    def __init__(self, *, start_period: int=None, end_period: int=None, **kwargs) -> None:
        super(PeriodRange, self).__init__(**kwargs)
        self.start_period = start_period
        self.end_period = end_period
