# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeSeriesEntity(Model):
    """TimeSeriesEntity.

    :param type:
    :type type: str
    :param id:
    :type id: int
    :param display:
    :type display: str
    :param secondary_display:
    :type secondary_display: str
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'id': {'key': 'id', 'type': 'int'},
        'display': {'key': 'display', 'type': 'str'},
        'secondary_display': {'key': 'secondaryDisplay', 'type': 'str'},
    }

    def __init__(self, *, type: str=None, id: int=None, display: str=None, secondary_display: str=None, **kwargs) -> None:
        super(TimeSeriesEntity, self).__init__(**kwargs)
        self.type = type
        self.id = id
        self.display = display
        self.secondary_display = secondary_display
