# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AggregatedItemRankResponse(Model):
    """AggregatedItemRankResponse.

    :param period:
    :type period: ~energycap.sdk.models.PeriodRange
    :param display_unit: The display unit of the values
    :type display_unit: str
    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.ItemRankResponse]
    """

    _attribute_map = {
        'period': {'key': 'period', 'type': 'PeriodRange'},
        'display_unit': {'key': 'displayUnit', 'type': 'str'},
        'data_details': {'key': 'dataDetails', 'type': '[ItemRankResponse]'},
    }

    def __init__(self, *, period=None, display_unit: str=None, data_details=None, **kwargs) -> None:
        super(AggregatedItemRankResponse, self).__init__(**kwargs)
        self.period = period
        self.display_unit = display_unit
        self.data_details = data_details
