# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUserRoleWithHiddenRequest(Model):
    """SystemUserRoleWithHiddenRequest.

    All required parameters must be populated in order to send to Azure.

    :param hidden: Set a system user role to be hidden or shown
     Roles Manage permission is required to access hidden roles
    :type hidden: bool
    :param system_user_role_name: Required. Name of the system user role <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type system_user_role_name: str
    :param description: Required. Description of the system user role <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 1000 characters</span>
    :type description: str
    :param permissions:
    :type permissions: ~energycap.sdk.models.PermissionsRequest
    """

    _validation = {
        'system_user_role_name': {'required': True, 'max_length': 64, 'min_length': 0},
        'description': {'required': True, 'max_length': 1000, 'min_length': 0},
    }

    _attribute_map = {
        'hidden': {'key': 'hidden', 'type': 'bool'},
        'system_user_role_name': {'key': 'systemUserRoleName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'permissions': {'key': 'permissions', 'type': 'PermissionsRequest'},
    }

    def __init__(self, **kwargs):
        super(SystemUserRoleWithHiddenRequest, self).__init__(**kwargs)
        self.hidden = kwargs.get('hidden', None)
        self.system_user_role_name = kwargs.get('system_user_role_name', None)
        self.description = kwargs.get('description', None)
        self.permissions = kwargs.get('permissions', None)
