# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactorCategoryResponse(Model):
    """GHGFactorCategoryResponse.

    :param factors: The Factors attached to a Category
    :type factors: list[~energycap.sdk.models.GHGFactorByCategoryChild]
    :param factor_category_id: The Factor Category identifier
    :type factor_category_id: int
    :param factor_category_info: The Factor Category Info
    :type factor_category_info: str
    """

    _attribute_map = {
        'factors': {'key': 'factors', 'type': '[GHGFactorByCategoryChild]'},
        'factor_category_id': {'key': 'factorCategoryId', 'type': 'int'},
        'factor_category_info': {'key': 'factorCategoryInfo', 'type': 'str'},
    }

    def __init__(self, *, factors=None, factor_category_id: int=None, factor_category_info: str=None, **kwargs) -> None:
        super(GHGFactorCategoryResponse, self).__init__(**kwargs)
        self.factors = factors
        self.factor_category_id = factor_category_id
        self.factor_category_info = factor_category_info
