# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupCategoryChild(Model):
    """MeterGroupCategoryChild.

    :param meter_group_category_id:
    :type meter_group_category_id: int
    :param meter_group_category_code:
    :type meter_group_category_code: str
    :param meter_group_category_info:
    :type meter_group_category_info: str
    """

    _attribute_map = {
        'meter_group_category_id': {'key': 'meterGroupCategoryId', 'type': 'int'},
        'meter_group_category_code': {'key': 'meterGroupCategoryCode', 'type': 'str'},
        'meter_group_category_info': {'key': 'meterGroupCategoryInfo', 'type': 'str'},
    }

    def __init__(self, *, meter_group_category_id: int=None, meter_group_category_code: str=None, meter_group_category_info: str=None, **kwargs) -> None:
        super(MeterGroupCategoryChild, self).__init__(**kwargs)
        self.meter_group_category_id = meter_group_category_id
        self.meter_group_category_code = meter_group_category_code
        self.meter_group_category_info = meter_group_category_info
