# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PeriodRangeComparison(Model):
    """General purpose period range comparison DTO.

    :param current_period_range:
    :type current_period_range: ~energycap.sdk.models.PeriodRange
    :param previous_period_range:
    :type previous_period_range: ~energycap.sdk.models.PeriodRange
    """

    _attribute_map = {
        'current_period_range': {'key': 'currentPeriodRange', 'type': 'PeriodRange'},
        'previous_period_range': {'key': 'previousPeriodRange', 'type': 'PeriodRange'},
    }

    def __init__(self, *, current_period_range=None, previous_period_range=None, **kwargs) -> None:
        super(PeriodRangeComparison, self).__init__(**kwargs)
        self.current_period_range = current_period_range
        self.previous_period_range = previous_period_range
