# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TrendTarget(Model):
    """Target data for use / cost / target emissions data.

    :param target_year: Target year
    :type target_year: int
    :param target_label: Target label
    :type target_label: str
    :param target_ytd_label: Target YTD label
    :type target_ytd_label: str
    :param target_value: Total value (use or cost) for the target year in the
     unit of the value being reported on
    :type target_value: float
    :param target_ytd_value: Year to date value (use or cost) for the target
     year in the unit of the value being reported on
    :type target_ytd_value: float
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'target_ytd_label': {'key': 'targetYTDLabel', 'type': 'str'},
        'target_value': {'key': 'targetValue', 'type': 'float'},
        'target_ytd_value': {'key': 'targetYTDValue', 'type': 'float'},
    }

    def __init__(self, *, target_year: int=None, target_label: str=None, target_ytd_label: str=None, target_value: float=None, target_ytd_value: float=None, **kwargs) -> None:
        super(TrendTarget, self).__init__(**kwargs)
        self.target_year = target_year
        self.target_label = target_label
        self.target_ytd_label = target_ytd_label
        self.target_value = target_value
        self.target_ytd_value = target_ytd_value
