# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MapPlaceChild(Model):
    """MapPlaceChild.

    :param place_id: The identifier for place
    :type place_id: int
    :param place_code: The place code
    :type place_code: str
    :param place_info: The place information
    :type place_info: str
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param floor_area: The floor area of the place, reported in the global
     area unit
    :type floor_area: float
    :param primary_use:
    :type primary_use: ~energycap.sdk.models.PrimaryUseChild
    :param energy_use_intensity: Energy Use Intensity (EUI) for the past
     period
    :type energy_use_intensity: float
    :param energy_cost_intensity: Energy Cost Intensity (ECI) for the past
     period
    :type energy_cost_intensity: float
    :param ghg_intensity: Green House Gas (GHG) Intensity for the past period
    :type ghg_intensity: float
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'floor_area': {'key': 'floorArea', 'type': 'float'},
        'primary_use': {'key': 'primaryUse', 'type': 'PrimaryUseChild'},
        'energy_use_intensity': {'key': 'energyUseIntensity', 'type': 'float'},
        'energy_cost_intensity': {'key': 'energyCostIntensity', 'type': 'float'},
        'ghg_intensity': {'key': 'ghgIntensity', 'type': 'float'},
    }

    def __init__(self, *, place_id: int=None, place_code: str=None, place_info: str=None, address=None, floor_area: float=None, primary_use=None, energy_use_intensity: float=None, energy_cost_intensity: float=None, ghg_intensity: float=None, **kwargs) -> None:
        super(MapPlaceChild, self).__init__(**kwargs)
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.address = address
        self.floor_area = floor_area
        self.primary_use = primary_use
        self.energy_use_intensity = energy_use_intensity
        self.energy_cost_intensity = energy_cost_intensity
        self.ghg_intensity = ghg_intensity
