# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RollingComparisonResponse(Model):
    """RollingComparisonResponse.

    :param data_displayed: Indicates the type of the data displayed. Eg:
     Actual, Calendarized or Normalized.
    :type data_displayed: str
    :param unit: The values unit
    :type unit: str
    :param period_range:
    :type period_range: ~energycap.sdk.models.PeriodRange
    :param data_details: The data details
    :type data_details: list[~energycap.sdk.models.RollingComparisonDetail]
    """

    _attribute_map = {
        'data_displayed': {'key': 'dataDisplayed', 'type': 'str'},
        'unit': {'key': 'unit', 'type': 'str'},
        'period_range': {'key': 'periodRange', 'type': 'PeriodRange'},
        'data_details': {'key': 'dataDetails', 'type': '[RollingComparisonDetail]'},
    }

    def __init__(self, *, data_displayed: str=None, unit: str=None, period_range=None, data_details=None, **kwargs) -> None:
        super(RollingComparisonResponse, self).__init__(**kwargs)
        self.data_displayed = data_displayed
        self.unit = unit
        self.period_range = period_range
        self.data_details = data_details
