# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OkObjectResult(Model):
    """OkObjectResult.

    :param value:  <span class='property-internal'>Required (defined)</span>
    :type value: object
    :param formatters:  <span class='property-internal'>Required
     (defined)</span>
    :type formatters: list[object]
    :param content_types:  <span class='property-internal'>Required
     (defined)</span>
    :type content_types: list[str]
    :param declared_type:  <span class='property-internal'>Required
     (defined)</span>
    :type declared_type: str
    :param status_code:  <span class='property-internal'>Required
     (defined)</span>
    :type status_code: int
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'object'},
        'formatters': {'key': 'formatters', 'type': '[object]'},
        'content_types': {'key': 'contentTypes', 'type': '[str]'},
        'declared_type': {'key': 'declaredType', 'type': 'str'},
        'status_code': {'key': 'statusCode', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(OkObjectResult, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.formatters = kwargs.get('formatters', None)
        self.content_types = kwargs.get('content_types', None)
        self.declared_type = kwargs.get('declared_type', None)
        self.status_code = kwargs.get('status_code', None)
