# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGSettings(Model):
    """GHGSettings.

    :param global_warming_assessment_report_id: The GHG Global Warming
     Assessment Report (AR) identifier
    :type global_warming_assessment_report_id: int
    :param global_warming_assessment_report_info: The GHG Global Warming
     Assessment Report (AR) name
    :type global_warming_assessment_report_info: str
    :param reporting_unit:
    :type reporting_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'global_warming_assessment_report_id': {'key': 'globalWarmingAssessmentReportId', 'type': 'int'},
        'global_warming_assessment_report_info': {'key': 'globalWarmingAssessmentReportInfo', 'type': 'str'},
        'reporting_unit': {'key': 'reportingUnit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(GHGSettings, self).__init__(**kwargs)
        self.global_warming_assessment_report_id = kwargs.get('global_warming_assessment_report_id', None)
        self.global_warming_assessment_report_info = kwargs.get('global_warming_assessment_report_info', None)
        self.reporting_unit = kwargs.get('reporting_unit', None)
